"" "递归调用" ""
def eachMovies(movies, levels=0):
        for each_item in movies:
                if isinstance(each_item, list):
                        eachMovies(each_item,levels+1)
                else :
                        for tab_stop in range(levels):
                                print("\t",end='')
                        print(each_item)



from distutils.core import setup

setup(
  name = 'aa_mengjianing',
  version = '1.1.0',
  py_modules = ['aa_mengjianing'],
  author = 'hfpython',
  author_email = 'hfpython@headfirstlabs.com',
  url = 'http://www.headfirstlabs.com',
  description = 'A simple printer of nested list'
)